Map

Struct Map 

pub struct Map<K: 'static, V: 'static> { /* private fields */ }
An immutable map.

Construct one with From or FromIterator.

Implementations

Source

impl<K, V> Map<K, V>

pub fn get_entry<Q>(&self, key: &Q) -> Option<(&K, &V)>
where Q: Hash + Eq + ?Sized, K: Borrow<Q>,

Returns the key-value entry corresponding to the given key, if present.

pub fn get<Q>(&self, key: &Q) -> Option<&V>
where Q: Hash + Eq + ?Sized, K: Borrow<Q>,

Returns a reference to the value corresponding to the given key, if present.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: Hash + Eq + ?Sized, K: Borrow<Q>,

Returns true if the map contains an entry for the given key.

pub fn len(&self) -> usize

Returns the number of entries in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no entries.

pub fn entries(&self) -> MapEntries<'_, K, V>

Returns an iterator over the key-value pairs of the map in an unspecified order.

pub fn keys(&self) -> MapKeys<'_, K, V>

Returns an iterator over the keys of the map in an unspecified order.

pub fn values(&self) -> MapValues<'_, K, V>

Returns an iterator over the values of the map in an unspecified order.

Source

impl<K, V> Map<K, V>
where K: Bake, V: Bake,

pub fn to_tokens(&self) -> TokenStream

Available on crate feature codegen only.

Serializes the Map into a token stream of literal Rust code that reconstructs it. Used for embedding in generated code.