pub struct Map<K: 'static, V: 'static> { /* private fields */ }Expand description
An immutable map.
Construct one with From or FromIterator.
Implementations
Sourceimpl<K, V> Map<K, V>
impl<K, V> Map<K, V>
Sourcepub fn get_entry<Q>(&self, key: &Q) -> Option<(&K, &V)>
pub fn get_entry<Q>(&self, key: &Q) -> Option<(&K, &V)>
Returns the key-value entry corresponding to the given key, if present.
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
pub fn get<Q>(&self, key: &Q) -> Option<&V>
Returns a reference to the value corresponding to the given key, if present.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains an entry for the given key.
Sourcepub fn entries(&self) -> MapEntries<'_, K, V> ⓘ
pub fn entries(&self) -> MapEntries<'_, K, V> ⓘ
Returns an iterator over the key-value pairs of the map in an unspecified order.